Learn R Programming

RareVariantVis (version 1.6.2)

CentromeresHg19: Positions of centromeres on all chromosomes, human genome 19

Description

CentromeresHg19 is a data frame providing positions of centromeres on all chromosomes of human genome 19 and its sizes. Size of centromere is also approximated in WinSize column to allow proper visualization of particular chromosomes.

Usage

data(CentromeresHg19)

Arguments

Value

Format

data frame

UCSC table browser